@@ -5,20 +5,20 @@ use warnings;
 
 =head1 NAME
 
-Mojolicious::Plugin::WWWSession - WWW:Session sessions for Mojolicious
+Mojolicious::Plugin::WWWSession - Use WWWW::Session with Mojolicious
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
 
-This module allows you to overwrite the standard Mojolicious session with a WWW:Session object and enjoy all the goodies it provides
+This module allows you to overwrite the standard Mojolicious session with a WWW::Session object and enjoy all the goodies it provides
 
 Example :
 
@@ -37,7 +37,39 @@ In you apllication module add the fallowing lines
     }
 
 
-Possible options for the plugin are :
+=head1 Using the session
+
+=head2 Settings values
+
+There are two ways you can save a value on the session :
+
+    $session->set('user',$user);
+    
+    or 
+    
+    $session->user($user);
+    
+If the requested field ("user" in the example above) already exists it will be 
+assigned the new value, if it doesn't it will be added.
+
+When you set a value for a field it will be validated first (see setup_field() ). 
+If the value doesn't pass validation the field will keep it's old value and the 
+set method will return 0. If everything goes well the set method will return 1.
+
+=head2 Retrieving values
+
+    my $user = $session->get('user');
+    
+    or
+    
+    my $user = $session->user();
+    
+If the requested field ("user" in the example above) already exists it will return 
+it's value, otherwise will return C<undef>
+
+=head1 Possible options for the plugin
+
+Here is an exmple containing the options you can pass to the plugin:
 
     {
     storage => [ 'File' => { path => '/tmp/sessions'},
@@ -47,9 +79,12 @@ Possible options for the plugin are :
     expires => 3600,
     fields => {
               user => {
-                      inflate => sub { return Some::Package->new( $_[0]->id() ) },
+                      inflate => sub { return Some::Package->new( $_[0] ) },
                       deflate => sub { $_[0]->id() },
-              }
+                      }
+              age => {
+                     filter => [21..99],
+                     }
     }
     
 See WWW:Session for more details on possible options and on how you can use the session
